@@ -64,7 +64,6 @@ class architype_interp(interp):
         for i in kid:
             if(i.name == 'attr_stmt'):
                 self.run_attr_stmt(i, obj)
-        self._can_compiled_flag = True
 
     def run_can_block(self, jac_ast):
         """
@@ -108,7 +107,7 @@ class architype_interp(interp):
                               kid[3])
             return obj
         else:
-            self.rt_error(f"Graph didn't produce root node!",
+            self.rt_error("Graph didn't produce root node!",
                           kid[3])
             return None
 
@@ -139,7 +138,7 @@ class architype_interp(interp):
 
         if (root_name not in nodes_def):
             del nodes_def
-            self.rt_error(f"Graph didn't produce root node!",
+            self.rt_error("Graph didn't produce root node!",
                           kid[1])
             return None
 
