@@ -32,10 +32,7 @@ class interp(machine_state):
         elif(kid[0].name == 'can_stmt'):
             if(obj.j_type == 'walker'):
                 self.run_can_stmt(kid[0], obj)
-            else:
-                obj = self.get_arch_for(obj)
-                if(not obj._can_compiled_flag):
-                    self.run_can_stmt(kid[0], obj)
+            #  Can statements in architype handled in architype load
 
     def run_has_stmt(self, jac_ast, obj):
         """
@@ -80,7 +77,7 @@ class interp(machine_state):
 
         if(var_name == '_private'):
             self.rt_error(
-                f'Has variable name of `_private` not allowed!', kid[0])
+                'Has variable name of `_private` not allowed!', kid[0])
         elif (var_name not in obj.context.keys()):  # Runs only once
             jac_value(self, ctx=obj,
                       name=var_name, value=var_val).write(kid[0], force=True)
@@ -315,7 +312,7 @@ class interp(machine_state):
                     break
                 self._loop_ctrl = None
                 if(loops > self._loop_limit):
-                    self.rt_error(f'Hit loop limit, breaking...', kid[0])
+                    self.rt_error('Hit loop limit, breaking...', kid[0])
                     self._loop_ctrl = 'break'
         else:
             var = self._jac_scope.get_live_var(
@@ -333,7 +330,7 @@ class interp(machine_state):
                     break
                 self._loop_ctrl = None
                 if(loops > self._loop_limit):
-                    self.rt_error(f'Hit loop limit, breaking...', kid[0])
+                    self.rt_error('Hit loop limit, breaking...', kid[0])
                     self._loop_ctrl = 'break'
 
     def run_while_stmt(self, jac_ast):
@@ -349,7 +346,7 @@ class interp(machine_state):
                 break
             self._loop_ctrl = None
             if(loops > self._loop_limit):
-                self.rt_error(f'Hit loop limit, breaking...', kid[0])
+                self.rt_error('Hit loop limit, breaking...', kid[0])
                 self._loop_ctrl = 'break'
 
     def run_ctrl_stmt(self, jac_ast):
@@ -401,11 +398,11 @@ class interp(machine_state):
             if(kid[2].token_text() in ['status', 'status_code']):
                 self.report_status = int(kid[4].token_text())
             else:
-                self.rt_error(f'Invalid report attribute to set', kid[2])
+                self.rt_error('Invalid report attribute to set', kid[2])
         else:
             report = self.run_expression(kid[1]).wrap(serialize_mode=True)
             if(not is_jsonable(report)):
-                self.rt_error(f'Report not Json serializable', kid[0])
+                self.rt_error('Report not Json serializable', kid[0])
             self.report.append(copy(report))
 
     def run_expression(self, jac_ast):
@@ -753,7 +750,7 @@ class interp(machine_state):
                     ret = None
                 return jac_value(self, value=ret)
             else:
-                self.rt_error(f'Unable to execute ability',
+                self.rt_error('Unable to execute ability',
                               kid[0])
         elif (kid[0].name == 'DBL_COLON'):
             if(len(kid) > 2):
@@ -812,14 +809,15 @@ class interp(machine_state):
             elif(isinstance(atom_res.value, edge)):
                 return atom_res
             elif(isinstance(atom_res.value, jac_set)):
-                res = jac_set()
-                for i in atom_res.value.obj_list():
-                    if(isinstance(i, edge)):
-                        res.add_obj(i)
-                    elif(isinstance(i, node)):
-                        res += self.obj_set_to_jac_set(
-                            self.current_node.attached_edges(i))
-                return jac_value(self, value=res)
+                return jac_value(self, value=self._relevant_edges)
+                # res = jac_set()
+                # for i in atom_res.value.obj_list():
+                #     if(isinstance(i, edge)):
+                #         res.add_obj(i)
+                #     elif(isinstance(i, node)):
+                #         res += self.obj_set_to_jac_set(
+                #             self.current_node.attached_edges(i))
+                # return jac_value(self, value=res)
             else:
                 self.rt_error(f'Cannot get edges from {atom_res.value}. '
                               f'Type {atom_res.jac_type()} invalid', kid[0])
@@ -977,6 +975,16 @@ class interp(machine_state):
                     result = jac_value(self, value=atom_res.value.sort())
                 elif (op == "clear"):
                     result = jac_value(self, value=atom_res.value.clear())
+                elif (op == "max"):
+                    result = jac_value(self, value=max(atom_res.value))
+                elif (op == "min"):
+                    result = jac_value(self, value=min(atom_res.value))
+                elif (op == "idx_of_max"):
+                    result = jac_value(
+                        self, value=atom_res.value.index(max(atom_res.value)))
+                elif (op == "idx_of_min"):
+                    result = jac_value(
+                        self, value=atom_res.value.index(min(atom_res.value)))
                 elif (len(kid) < 2 and op == "pop"):
                     result = jac_value(self, value=atom_res.value.pop())
                 if (result):
@@ -1118,12 +1126,16 @@ class interp(machine_state):
             return jac_value(self, value=result)
 
         elif (kid[0].name == 'edge_ref'):
+            relevant_edges = self.run_edge_ref(kid[0])
             result = self.edge_to_node_jac_set(self.run_edge_ref(kid[0]))
             if(len(kid) > 1 and kid[1].name == 'node_ref'):
                 nres = self.run_node_ref(kid[1])
                 if(len(kid) > 2):
                     nres = self.run_filter_ctx(kid[2], nres)
                 result = result * nres
+                relevant_edges = self.edges_filter_on_nodes(relevant_edges,
+                                                            result)
+            self._relevant_edges = relevant_edges
             return jac_value(self, value=result)
 
     def run_node_ref(self, jac_ast, is_spawn=False):
