@@ -1,194 +1,3 @@
-ll_proto = \
-    """
-    node life {
-        has anchor owner;
-        can infer.year_from_date;
-    }
-
-    node year {
-        has anchor year;
-        can infer.month_from_date;
-    }
-
-    node month {
-        has anchor month;
-        can infer.year_from_date;
-        can infer.week_from_date;
-    }
-
-    node week {
-        has anchor week;
-        can infer.month_from_date;
-        can infer.day_from_date, date.day_from_date;
-    }
-
-    node day: has anchor day;
-
-    node workette {
-        has  name, order, date, owner, status, snooze_till;
-        has note, is_MIT, is_ritual;
-    }
-
-    edge past;
-
-    edge parent;
-
-    walker get_day {
-        has date;
-        life: take --> node::year == infer.year_from_date(date);
-        year: take --> node::month == infer.month_from_date(date);
-        month: take --> node::week == infer.week_from_date(date);
-        week: take --> node::day == date.day_from_date(date);
-        day: report here;
-        report false;
-    }
-
-    walker get_latest_day {
-        has before_date;
-        has anchor latest_day;
-        if(!before_date): before_date = std.time_now();
-        if(!latest_day): latest_day = 0;
-
-        life {
-            ignore --> node::year > infer.year_from_date(before_date);
-            take net.max(--> node::year);
-        }
-        year {
-            ignore node::month > infer.month_from_date(before_date);
-            take net.max(--> node::month)
-            else {
-                ignore here;
-                take <-- node::life;
-            }
-        }
-        month {
-            ignore node::week > infer.week_from_date(before_date);
-            take net.max(--> node::week)
-            else {
-                ignore here;
-                take <-- node::year == infer.year_from_date(before_date);
-            }
-        }
-        week {
-            ignore node::day > infer.day_from_date(before_date);
-            take net.max(--> node::day)
-            else {
-                ignore here;
-                take <-- node::month == infer.month_from_date(before_date);
-            }
-        }
-        day {
-            latest_day = here;
-            report here;
-        }
-    }
-
-    walker get_gen_day {
-        has date;
-        has anchor day_node;
-        if(!date): date=std.time_now();
-        root: take --> node::life;
-        life: take --> node::year == infer.year_from_date(date) else {
-                new = spawn here --> node::year ;
-                new.year = infer.year_from_date(date);
-                take --> node::year == infer.year_from_date(date);
-            }
-        year: take --> node::month == infer.month_from_date(date) else {
-                new = spawn here --> node::month;
-                new.month = infer.month_from_date(date);
-                take --> node::month == infer.month_from_date(date);
-            }
-        month: take --> node::week == infer.week_from_date(date) else {
-                new = spawn here --> node::week;
-                new.week = infer.week_from_date(date);
-                take --> node::week == infer.week_from_date(date);
-            }
-        week: take --> node::day == infer.day_from_date(date) else {
-                latest_day = spawn here walker::get_latest_day;
-                new = spawn here --> node::day;
-                new.day = infer.day_from_date(date);
-                if(latest_day and infer.day_from_date(date) ==
-                    infer.day_from_date(std.time_now())) {
-                    spawn latest_day walker::carry_forward(parent=new);
-                    take new;
-                }
-                elif(latest_day) {
-                    take latest_day;
-                }
-                else: take new;
-            }
-        day {
-            day_node = here;
-            take --> node::workette;
-        }
-        workette {
-            report here;
-            take --> node::workette;
-        }
-    }
-
-    walker get_sub_workettes {
-        report here;
-        workette: take --> node::workette;
-    }
-
-    walker carry_forward {
-        has parent;
-        day {
-            take --> node::workette;
-        }
-        workette {
-            if(here.status == 'done' or
-            here.status == 'eliminated') {
-                disengage;
-            }
-            new_workette = spawn here <-[past]- node::workette;
-            new_workette <-[parent]- parent;
-            new_workette := here;
-            spawn --> node::workette
-                walker::carry_forward(parent=new_workette);
-        }
-    }
-
-    walker gen_rand_life {
-        has num_workettes;
-        root: take --> node::life;
-
-        life {
-            num_workettes = 10;
-            num_days = rand.integer(2, 4);
-            for i=0 to i<num_days by i+=1 {
-                spawn here walker::get_gen_day(
-                    date=rand.time("2019-01-01", "2019-12-31")
-                );
-            }
-            take -->;
-        }
-        year, month, week { take -->; }
-        day, workette {
-            if(num_workettes == 0): disengage;
-            gen_num = rand.integer(5, 8);
-            for i=0 to i<gen_num by i+=1 {
-                spawn here -[parent]-> node::workette(name=rand.sentence());
-            }
-            take --> ;
-            num_workettes -= 1;
-        }
-    }
-
-    walker init {
-        has owner;
-        has anchor life_node;
-        take (--> node::life == owner) else {
-            life_node = spawn here --> node::life;
-            life_node.owner = owner;
-            disengage;
-        }
-    }
-
-
-    """
-
 prog0 = \
     """
     node testnode:0 {
@@ -604,7 +413,7 @@ edge_access = \
 
             e = -[apple]->.edge[0];
             e.v1 = 7;
-            e = --> node::testnode .edge[1];
+            e = (--> node::testnode).edge[1];
             e.x1=8;
         }
     }
@@ -1304,3 +1113,40 @@ graph_in_graph = \
         report here;
     }
     """
+
+
+min_max_on_list = \
+    """
+    walker init {
+        a = [45, 3, 531.0, 3, 6, 531.1];
+
+        report a.l::max;
+        report a.l::min;
+        report a.l::idx_of_max;
+        report a.l::idx_of_min;
+    }
+    """
+
+edge_bug = \
+    """
+    node plain;
+
+    edge g;
+
+    walker init {
+        root {
+            nd = spawn here -[g]-> node::plain;
+            nd -[g]-> nd;
+            spawn nd -[g]-> node::plain;
+            spawn nd -[g]-> node::plain;
+            a = spawn nd <-[g]- node::plain;
+            spawn nd <-[g]- node::plain;
+            nd -[g]-> a;
+        }
+        take -[g]->;
+        plain {
+            report -[g]->.edge;
+            disengage;
+        }
+    }
+    """
