@@ -99,3 +99,24 @@ nd_equals_error_correct_line = \
         }
     }
     """
+
+
+str = \
+    """
+    node plain {
+        can show with entry {
+            std.out("Showing");
+        }
+    }
+
+    walker init {
+        root {
+            spawn here --> node::plain;
+        }
+    }
+
+    walker travel {
+        take -->;
+    }
+
+    """
