@@ -77,3 +77,24 @@ class jac_tests(TestCaseHelper, TestCase):
         report = mast.general_interface_to_api(
             api_name='walker_run', params={'name': 'init'})
         self.assertIn("line 3", report['errors'][0])
+
+    def test_strange_ability_bug(self):
+        self.logger_on()
+        mast = master(h=mem_hook())
+        mast.sentinel_register(
+            name='test', code=jtp.strange_ability_bug)
+        report = mast.general_interface_to_api(
+            api_name='walker_run', params={'name': 'travel'})['report']
+        mast.sentinel_register(
+            name='test', code=jtp.strange_ability_bug, auto_run="")
+        report += mast.general_interface_to_api(
+            api_name='walker_run', params={'name': 'travel'})['report']
+        ir = mast.sentinel_get(mode='ir',
+                               snt=mast.active_snt())
+        mast.sentinel_set(code=ir, snt=mast.active_snt(), mode='ir')
+        report += mast.general_interface_to_api(
+            api_name='walker_run', params={'name': 'travel'})['report']
+        report += mast.general_interface_to_api(
+            api_name='walker_run', params={'name': 'travel'})['report']
+        self.assertEqual(
+            report, ['Showing', 'Showing', 'Showing', 'Showing'])
